/*
Copyright © 2023 Philipp Wolfer <phw@uploadedlobster.com>

This file is part of Scotty.

Scotty is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later version.

Scotty is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
Scotty. If not, see <https://www.gnu.org/licenses/>.
*/
package cmd

import (
	"github.com/spf13/cobra"
	"go.uploadedlobster.com/scotty/internal/backends"
	"go.uploadedlobster.com/scotty/internal/models"
)

// lovesCmd represents the loves command
var lovesCmd = &cobra.Command{
	Use:   "loves",
	Short: "Transfer loves between two services",
	Long:  `Transfers loves between two configured services.`,
	Run: func(cmd *cobra.Command, args []string) {
		exp, imp, err := resolveBackends[models.LovesExport, models.LovesImport, models.LovesResult](cmd)
		cobra.CheckErr(err)
		exp.processor = backends.LovesExportProcessor{
			Backend: exp.backend,
		}
		imp.processor = backends.LovesImportProcessor{
			Backend: imp.backend,
		}
		cmdExportImport(cmd, "loves", exp, imp)
	},
}

func init() {
	beamCmd.AddCommand(lovesCmd)

	// Here you will define your flags and configuration settings.

	// Cobra supports Persistent Flags which will work for this command
	// and all subcommands, e.g.:
	// lovesCmd.PersistentFlags().String("foo", "", "A help for foo")

	// Cobra supports local flags which will only run when this command
	// is called directly, e.g.:
	// lovesCmd.Flags().BoolP("toggle", "t", false, "Help message for toggle")
}
